@@ -11,8 +11,10 @@
 #' of `r glue::glue_collapse(paste0("[", glue::double_quote(default_chores), "]", "[", default_chores, "_helper", "]"), ", ", last = " or ")`,
 #' though custom helpers can be added with [prompt_new()].
 #' @param .chores_chat An ellmer Chat, e.g.
-#' `function() ellmer::chat_claude()`. Defaults to the option by the same name,
-#' so e.g. set `options(.chores_chat = ellmer::chat_claude())` in your
+#' `ellmer::chat_claude()`. Defaults to the `chores.chat` option,
+#' so e.g. set
+#' `options(chores.chat = ellmer::chat_claude(model = "claude-3-7-sonnet-20250219"))`
+#'  in your
 #' `.Rprofile` to configure chores with ellmer every time you start a new R session.
 #'
 #' @returns
@@ -22,22 +24,22 @@
 #' # requires an API key and sets options
 #' \dontrun{
 #' # to create a chat with claude:
-#' .init_helper(.chores_chat = ellmer::chat_claude())
+#' .init_helper(.chores_chat = ellmer::chat_claude(model = "claude-3-7-sonnet-20250219"))
 #'
-#' # or with OpenAI's 4o-mini:
+#' # or with OpenAI's GPT-4o-mini:
 #' .init_helper(.chores_chat = ellmer::chat_openai(model = "gpt-4o-mini"))
 #'
-#' # to set OpenAI's 4o-mini as the default model powering chores, for example,
+#' # to set OpenAI's GPT-4o-mini as the default model powering chores, for example,
 #' # set the following option (possibly in your .Rprofile, if you'd like
 #' # them to persist across sessions):
 #' options(
-#'   .chores_chat = ellmer::chat_openai(model = "gpt-4o-mini")
+#'   chores.chat = ellmer::chat_openai(model = "gpt-4o-mini")
 #' )
 #' }
 #' @export
 .init_helper <- function(
   chore = NULL,
-  .chores_chat = getOption(".chores_chat")
+  .chores_chat = get_chores_chat()
 ) {
   check_chore(chore, allow_default = TRUE)
   if (!chore %in% list_helpers()) {
