@@ -32,10 +32,7 @@ list_helpers <- function() {
 }
 
 load_chores_directory <- function() {
-  chores_dir <- getOption(
-    ".chores_dir",
-    default = file.path("~", ".config", "chores")
-  )
+  chores_dir <- get_chores_dir()
   if (!is.null(chores_dir) && dir.exists(chores_dir)) {
     directory_load(chores_dir)
   }
