@@ -2,7 +2,9 @@ test_that(".helper_last is up to date with most recent helper", {
   skip_if(identical(Sys.getenv("ANTHROPIC_API_KEY"), ""))
   skip_if(identical(Sys.getenv("OPENAI_API_KEY"), ""))
   skip_if_not_installed("withr")
-  withr::local_options(.chores_chat = ellmer::chat_claude())
+  withr::local_options(
+    .chores_chat = ellmer::chat_claude(model = "claude-3-7-sonnet-20250219")
+  )
 
   .init_helper("cli")
   expect_snapshot(env_get(chores_env(), ".helper_last"))
